@@ -508,4 +508,24 @@ class Mftool():
                 response = yf.download(code,start=start,end=end)
             elif period is not None:
                 response = yf.download(code,period=period)
-            return get_Dataframe(response,as_dataframe)
\ No newline at end of file
+            return get_Dataframe(response,as_dataframe)
+        
+    def get_scheme_info(self, code, as_json=True):
+        """
+        gets the complete information for a given scheme code, only use NEW scheme codes
+        :Parameters:
+            code : str
+                Scheme code to download
+            as_json: True / False
+                Default is True
+        :return: JSON or None
+        :raises: HTTPError, URLError
+        """
+        code = str(code)
+        if self.is_code(code):
+            code = code + ".BO"
+            mf = yf.Ticker(code)
+            response = mf.info
+        return self.render_response(response, as_json)
+            
+ 
\ No newline at end of file
